{% load static %}
<!DOCTYPE html>
<html lang="en">
<head>
	<meta charset="UTF-8">
	<meta name="viewport" content="width=device-width, initial-scale=1.0">
	{% block stylesheet %}
	<link rel="stylesheet" href="{% static 'mosaic/css/style.css' %}">
	<link rel="stylesheet" href="{% static 'mosaic/css/pygments.css' %}">
	{% endblock %}
	{% block stylesheet_extra %}
	{% endblock %}
	<title>{{ CONSTANTS.site.title }}{% block title %}{% endblock %}</title>
	<meta name="description" content="{% block meta_description %}{{ CONSTANTS.site.description }}{% endblock %}">
	<link rel="canonical" href="{% block canonical %}{{ request.build_absolute_uri }}{% endblock %}">
	<meta property="og:site_name" content="{{ CONSTANTS.site.title }}">
	{% block og_tags %}
	<meta property="og:title" content="{{ CONSTANTS.site.title }}">
	<meta property="og:description" content="{{ CONSTANTS.site.description }}">
	<meta property="og:url" content="{{ request.build_absolute_uri }}">
	<meta property="og:type" content="website">
	{% endblock %}
	{% block twitter_tags %}
	<meta name="twitter:card" content="summary">
	<meta name="twitter:title" content="{{ CONSTANTS.site.title }}">
	<meta name="twitter:description" content="{{ CONSTANTS.site.description }}">
	{% endblock %}
	{% if namespace %}<link rel="alternate" type="application/rss+xml" title="{{ CONSTANTS.site.title }} RSS Feed" href="{% url 'feed' namespace %}">{% endif %}
	{% include "includes/header.html" %}
	{% if author %}{% for link in author.rel_me_links.all %}
	<link rel="me" href="{{ link.url }}">
	{% endfor %}{% endif %}
	{% block head_extra %}{% endblock %}
</head>
<body class="wrap">
  {% block body %}
	<header>
		<nav>
			<a href="{% url 'home' %}">{{ CONSTANTS.site.title }}</a>
			<a href="{% url 'ns-home' 'private' %}">Friends & Family</a>
		</nav>
	</header>
	<main>
		{% block content %}{% endblock %}
	</main>
	<footer>
		<hr />
		<div class="links">
			{% include "includes/hcard.html" %}
			<ul class="list-plain">
			<li>Subscribe with <a href="{% url 'feed' namespace %}">RSS</a>.</li>
			<li>Made for the <a href="https://indieweb.org">indieweb</a> with <a href="https://app.radicle.xyz/nodes/iris.radicle.xyz/rad:zVdCS3rdBtnLLui7jaHTf4X9j6FD">Mosaic</a>.</li>
			{% block footer_extra %}{% endblock %}
			</ul>
		</div>
	</footer>
	{% endblock %}
</body>
</html>
