# Generated by Django 6.0.2 on 2026-02-08 08:57

import secrets
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_mosaic", "0002_post_secret_id"),
    ]

    operations = [
        migrations.AlterField(
            model_name="post",
            name="secret_id",
            field=models.CharField(default=secrets.token_hex, max_length=128),
        ),
    ]
