# Generated by Django 6.0.2 on 2026-02-16 16:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_mosaic', '0010_remove_draft_content'),
    ]

    operations = [
        migrations.AddField(
            model_name='post',
            name='published_version_id',
            field=models.IntegerField(blank=True, null=True),
        ),
    ]
