# Generated by Django 6.0.2 on 2026-02-16 12:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_mosaic', '0009_tag_slug'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='post',
            name='draft_content',
        ),
    ]
