{% extends "base.html" %}
{% load markdownify %}

{% block content %}

{% include "includes/about.html" %}

<hr/>

<h2>Writing</h2>
<ul class="h-feed">
{% for post in posts %}
{% include "post-detail-include.html" %}
{% endfor %}
</ul>

<hr />

<h2>Topics</h2>
{% for t in tags %}
<a href="{{ t.get_absolute_url }}">{{ t.name }}</a>{% if not forloop.last %}, {% endif %}
{% endfor %}

{% endblock %}
