{% extends "base.html" %}

{% block content %}
<h2>Posts for <strong>{{ tag.name }}</strong></h2>
<ul class="h-feed">
{% for post in posts %}
{% include "post-detail-include.html" %}
{% endfor %}
</ul>
{% endblock %}
