# Generated by Django 6.0.2 on 2026-02-13 08:24

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_mosaic", "0005_regenerate_duplicate_secret_ids"),
    ]

    operations = [
        migrations.AddField(
            model_name="author",
            name="display_name",
            field=models.CharField(blank=True, default="", max_length=256),
        ),
        migrations.AddField(
            model_name="author",
            name="email",
            field=models.EmailField(blank=True, default="", max_length=254),
        ),
        migrations.AddField(
            model_name="author",
            name="note",
            field=models.CharField(blank=True, default="", max_length=1024),
        ),
        migrations.AddField(
            model_name="author",
            name="photo_url",
            field=models.URLField(blank=True, default="", max_length=512),
        ),
        migrations.AddField(
            model_name="author",
            name="url",
            field=models.URLField(blank=True, default="", max_length=512),
        ),
        migrations.AlterField(
            model_name="author",
            name="h_card",
            field=models.JSONField(blank=True, default=dict),
        ),
        migrations.CreateModel(
            name="RelMeLink",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("url", models.URLField(max_length=512)),
                ("label", models.CharField(blank=True, default="", max_length=256)),
                (
                    "author",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="rel_me_links",
                        to="django_mosaic.author",
                    ),
                ),
            ],
            options={
                "ordering": ["pk"],
            },
        ),
    ]
