<p>This could be your little home on the internet.</p>
<p>Mosaic is a project that helps you claim your own space on the internet. It's supposed to be yours, away from social media and tech giants.</p>
<p>It integrates well with the <a href="https://indieweb.org">IndieWeb</a> movement, which is all about normal people like you building their homes on the internet. The three guiding principles of the IndieWeb are: your content is yours, you are better connected, you are in control.</p>
<p>Mosaic supports:</p>
<ul>
<li>webmention</li>
<li>some microformats (h-entry)</li>
<li>RSS feeds</li>
<li>A private space for private posts</li>
</ul>
<p>Mosaic is not supposed to be a one-and-done thing. The spirit of the IndieWeb is also understanding of the technology. As such, an effort has been made to keep the code base accessible and easy to understand.</p>
<p>If you're using it to build your website, please send us a link - we'd love to hear about it!</p>

