# Generated by Django 6.0.2 on 2026-02-13 13:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_mosaic", "0006_author_display_name_author_email_author_note_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="contentimage",
            name="is_featured",
            field=models.BooleanField(default=False),
        ),
    ]
