# Generated by Django 6.0.2 on 2026-02-13 07:58

import django_mosaic.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_mosaic", "0003_alter_post_secret_id"),
    ]

    operations = [
        migrations.AlterField(
            model_name="post",
            name="secret_id",
            field=models.CharField(
                default=django_mosaic.models.generate_secret_id,
                max_length=128,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="post",
            name="title",
            field=models.CharField(max_length=512),
        ),
    ]
