# Generated by Django 6.0.2 on 2026-02-08 08:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_mosaic", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="post",
            name="secret_id",
            field=models.CharField(
                default="5abf335a0aa2420cdecca6f0e53a85d4b3879b0cdb0cea2b43f864fafaed425a",
                max_length=128,
            ),
        ),
    ]
