# Generated by Django 6.0.2 on 2026-02-14 09:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_mosaic", "0007_contentimage_is_featured"),
    ]

    operations = [
        migrations.AddField(
            model_name="post",
            name="draft_content",
            field=models.TextField(blank=True, default=None, null=True),
        ),
    ]
